==> haskell-either-5.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1
id: either-5.0.1-IFu8s2gcvGzHwCvSKyfFEg
key: either-5.0.1-IFu8s2gcvGzHwCvSKyfFEg
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: ddcae30bb5d723e5edbd8a8dc29d5f0f
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.4.3/site-local/either-5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/either-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/either-5.0.1
hs-libraries: HSeither-5.0.1-IFu8s2gcvGzHwCvSKyfFEg
depends:
    base-4.11.1.0 bifunctors-5.5.3-DfLKZddWnIEB6abRlxmEkC mtl-2.2.2
    profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD
    semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-DfLKZddWnIEB6abRlxmEkC=295557de758901ec7b2a2a06ded5bb97
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD=c4f5caccd7270609435ed7e692ca0cda
             semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ=fefe65a9667b054c22e0c4972c268b42
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1
id: either-5.0.1-irt2HUkdIX943j81Futox
key: either-5.0.1-irt2HUkdIX943j81Futox
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: cb4e4c125b76e2a4fb7aae3e6b26c05d
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.4.3/site-local/either-5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/either-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/either-5.0.1
hs-libraries: HSeither-5.0.1-irt2HUkdIX943j81Futox
depends:
    base-4.11.1.0 bifunctors-5.5.3-BIgJKb8FSuPAayKoWZoZXs mtl-2.2.2
    profunctors-5.3-3u867uKeeneFGUkrebkTSU
    semigroupoids-5.3.1-CeMZ4nWzebBGv5gAlve2hz
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-BIgJKb8FSuPAayKoWZoZXs=0426fbb9242519da49cd2883092459ef
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.3-3u867uKeeneFGUkrebkTSU=7c1592d4b10059df053f39319b70fed8
             semigroupoids-5.3.1-CeMZ4nWzebBGv5gAlve2hz=603c5acfe7d6290aa15d3051aa8734ec
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
